fails:Hash#to_h with block raises ArgumentError if block returns longer or shorter array
fails:Hash#to_h with block raises TypeError if block returns something other than Array
fails:Hash#to_h with block does not coerce returned pair to Array with #to_a
