fails:Struct.new keyword_init: true option new class instantiation raises ArgumentError when passed not declared keyword argument
fails:Struct.new raises ArgumentError when there is a duplicate member
fails:Struct.new keyword_init: true option raises when there is a duplicate member
